Key

Enum Key 

pub enum Key {
Show 59 variants Ctrl, Shift, Space, Backspace, Enter, Alt, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, ArrowUp, ArrowDown, ArrowLef, ArrowRight, D0, D1, D2, D3, D4, D5, D6, D7, D8, D9, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, Escape,
}

Variants



Ctrl



Shift



Space



Backspace



Enter



Alt



A



B



C



D



E



F



G



H



I



J



K



L



M



N



O



P



Q



R



S



T



U



V



W



X



Y



Z



ArrowUp



ArrowDown



ArrowLef



ArrowRight



D0



D1



D2



D3



D4



D5



D6



D7



D8



D9



F1



F2



F3



F4



F5



F6



F7



F8



F9



F10



F11



F12



Escape